SnekCheck
=========
|image0|

A generalized, highly customizable python linter 

All configuration (except for pylint) is done in one file: .snekrc

full .snekrc:

.. code:: ini

    TODO

**Not all flake8 extensions are supported!**

::

    usage: snekchek [-h] [--json] [--config-file CONFIG_FILE]
       
       optional arguments:
         -h, --help            show this help message and exit
         --json                output in JSON format
         --config-file CONFIG_FILE
                               Select config file to use

.. |image0| image:: https://travis-ci.org/IzunaDevs/SnekChek.svg?branch=master

